OC.L10N.register(
    "ownpad_lite",
    {
    "Document was shared" : "문서 공유됨",
    "User %s shared quick document %s with you." : "%s 님이 빠른 문서 %s을(를) 공유했습니다.",
    "My pad" : "내 패드",
    "Settings" : "설정",
    "Pad Title" : "패드 제목",
    "Open" : "열기",
    "Share with" : "다음으로 공유",
    "Share" : "공유",
    "Etherpad service URL" : "Etherpad 서비스 URL",
    "Username" : "사용자 이름",
    "Save" : "저장"
},
"nplurals=1; plural=0;");
